var searchData=
[
  ['name_0',['name',['../classlibcamera_1_1PixelFormatInfo.html#a1aeacb31949df565216bb98d665125dd',1,'libcamera::PixelFormatInfo::name'],['../structlibcamera_1_1IPAModuleInfo.html#ac8fb4c26b65a2fbad350fc185445164d',1,'libcamera::IPAModuleInfo::name']]],
  ['noisereductionmode_1',['NoiseReductionMode',['../namespacelibcamera_1_1controls_1_1draft.html#a6e1f2f0ceea5e93c3ce52b19feb3219c',1,'libcamera::controls::draft']]],
  ['noisereductionmodevalues_2',['NoiseReductionModeValues',['../namespacelibcamera_1_1controls_1_1draft.html#a544c87fa9fc0a0edf3add88be91a92e8',1,'libcamera::controls::draft']]]
];
